@@ -12,16 +12,16 @@
 #     Z-score normalization
 ## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
 
-transform = function( x, method = c( "minmax", "zscore" ), na.rm = FALSE ) 
+transform = function( x, method = c( "minmax", "zscore" ), columns = NULL, na.rm = FALSE ) 
 {
     method = match.arg( method )
     
-    if( method == "minmax" ) x_trans = liver::minmax( x = x, na.rm = na.rm )
-    if( method == "zscore" ) x_trans = liver::zscore( x = x, na.rm = na.rm )
+    if( method == "minmax" ) x_trans = liver::minmax( x = x, columns = columns, na.rm = na.rm )
+    if( method == "zscore" ) x_trans = liver::zscore( x = x, columns = columns, na.rm = na.rm )
     
     return( x_trans )
 }
-   
+
 ## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
 
 
